summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/godabil.cc
diff options
context:
space:
mode:
authorCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
committerCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
commit9701b3016d5d0d1fb67185e7abd675a0de0c129a (patch)
tree784d87393b77498a551a18836128c0bf0f14be6a /crawl-ref/source/godabil.cc
parent0a3c856d3d36b49a8430fe9468d2f11ae234f9c8 (diff)
downloadcrawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.tar.gz
crawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.zip
Rename Feawn
In most places Feawn is now referred to as "Fedhas," its long name (used in the religion screen) is "Fedhas Madash"
Diffstat (limited to 'crawl-ref/source/godabil.cc')
-rw-r--r--crawl-ref/source/godabil.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/crawl-ref/source/godabil.cc b/crawl-ref/source/godabil.cc
index b203cc95a0..fa6c766e0e 100644
--- a/crawl-ref/source/godabil.cc
+++ b/crawl-ref/source/godabil.cc
@@ -312,11 +312,11 @@ void yred_make_enslaved_soul(monsters *mon, bool force_hostile,
}
}
// Feawn allows worshipers to walk on top of stationary plants and
// fungi.
-bool feawn_passthrough(const monsters * target)
+bool fedhas_passthrough(const monsters * target)
{
- return (target && you.religion == GOD_FEAWN
+ return (target && you.religion == GOD_FEDHAS
&& mons_is_plant(target)
&& mons_is_stationary(target)
&& (target->type != MONS_OKLOB_PLANT
@@ -464,7 +464,7 @@ static int _create_plant(coord_def & target)
0,
target,
MHITNOT,
- MG_FORCE_PLACE, GOD_FEAWN));
+ MG_FORCE_PLACE, GOD_FEDHAS));
if (plant != -1)
@@ -567,7 +567,7 @@ bool sunlight()
target,
MHITNOT,
MG_FORCE_PLACE,
- GOD_FEAWN));
+ GOD_FEDHAS));
if (plant != -1 && observe_cell(target))
plant_count++;
@@ -882,7 +882,7 @@ int rain(const coord_def &target)
0,
*rad,
MHITNOT,
- MG_FORCE_PLACE, GOD_FEAWN));
+ MG_FORCE_PLACE, GOD_FEDHAS));
if (plant != -1)
spawned_count++;
@@ -1112,7 +1112,7 @@ bool evolve_flora()
};
current_plant->upgrade_type(current_target.new_type, true, true);
- current_plant->god = GOD_FEAWN;
+ current_plant->god = GOD_FEDHAS;
current_plant->attitude = ATT_FRIENDLY;
current_plant->flags |= MF_CREATED_FRIENDLY;
current_plant->flags |= MF_ATT_CHANGE_ATTEMPT;
@@ -312,11 +312,11 @@ void yred_make_enslaved_soul(monsters *mon, bool force_hostile,
}
}
-// Feawn allows worshipers to walk on top of stationary plants and
+// Fedhas allows worshipers to walk on top of stationary plants and
// fungi.